<?php
include('mysqli_connect_w10.php'); //database connection

function getEmployeeNumbers($dbc) { //gathering employee numbers 
    $query = "SELECT employeeNumber FROM employees";
    $result = mysqli_query($dbc, $query);
    return $result ?: false;
}

function searchEmployee($dbc, $employeeNumber) { //searching employee numbers 
    $query = "SELECT * FROM employees WHERE employeeNumber = ?";
    $stmt = mysqli_prepare($dbc, $query);
    mysqli_stmt_bind_param($stmt, 'i', $employeeNumber);
    mysqli_stmt_execute($stmt);
    $result = mysqli_stmt_get_result($stmt);

    echo "<div class='result-section'>";
    if (mysqli_num_rows($result) > 0) {
        echo "<h3>Employee Search Results:</h3>";
        echo "<p>Found " . mysqli_num_rows($result) . " match(es).</p>";
        while ($row = mysqli_fetch_assoc($result)) {
            echo "<div class='card'>
                    <p><strong>Employee Number:</strong> {$row['employeeNumber']}</p>
                    <p><strong>Name:</strong> {$row['firstName']} {$row['lastName']}</p>
                  </div>";
        }
    } else {
        echo "<p>No employee found with that employee number.</p>";
    }
    echo "</div>";
}

function searchOrdersByDate($dbc, $year, $month, $day) { //date range search 
    $query = "SELECT * FROM orders WHERE YEAR(orderDate) = ? AND MONTH(orderDate) = ? AND DAY(orderDate) = ?";
    $stmt = mysqli_prepare($dbc, $query);
    mysqli_stmt_bind_param($stmt, 'iii', $year, $month, $day);
    mysqli_stmt_execute($stmt);
    $result = mysqli_stmt_get_result($stmt);

    echo "<div class='result-section'>";
    if (mysqli_num_rows($result) > 0) {
        echo "<h3>Order Search Results:</h3>";
        echo "<p>Found " . mysqli_num_rows($result) . " match(es).</p>";
        while ($row = mysqli_fetch_assoc($result)) {
            echo "<div class='card'>
                    <p><strong>Order Number:</strong> {$row['orderNumber']}</p>
                    <p><strong>Order Date:</strong> {$row['orderDate']}</p>
                    <p><strong>Status:</strong> {$row['status']}</p>
                  </div>";
        }
    } else {
        echo "<p>No orders found for the selected date.</p>";
    }
    echo "</div>";
}

if (isset($_POST['employeeSearch'])) {
    $employeeNumber = $_POST['employeeNumber'];
    searchEmployee($dbc, $employeeNumber);
}

if (isset($_POST['orderSearch'])) {
    $year = $_POST['year'];
    $month = $_POST['month'];
    $day = $_POST['day'];
    searchOrdersByDate($dbc, $year, $month, $day);
}
?>

<!DOCTYPE html> 
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Employee & Order Search</title>
    <style>
        body {
            font-family: 'Segoe UI', sans-serif;
            background-color: #f7f9fb;
            color: #333;
            padding: 40px;
        }

        h2, h3 {
            color: #2c3e50;
        }

        form {
            background-color: #ffffff;
            border: 1px solid #ddd;
            border-radius: 8px;
            padding: 20px;
            margin-bottom: 30px;
            box-shadow: 0 3px 6px rgba(0,0,0,0.05);
        }

        label {
            display: inline-block;
            margin-right: 10px;
            font-weight: bold;
            margin-bottom: 8px;
        }

        select, input[type="text"] {
            padding: 8px;
            border-radius: 4px;
            border: 1px solid #ccc;
            margin: 10px 0;
            width: 180px;
        }

        button {
            background-color: #3498db;
            color: white;
            border: none;
            padding: 10px 16px;
            font-size: 15px;
            border-radius: 4px;
            cursor: pointer;
            margin-top: 10px;
        }

        button:hover {
            background-color: #2980b9;
        }

        hr {
            border-top: 1px solid #ccc;
            margin: 40px 0;
        }

        .result-section {
            background-color: #ecf0f1;
            padding: 20px;
            border-radius: 8px;
            margin-top: 30px;
        }

        .card {
            background-color: white;
            padding: 15px;
            border: 1px solid #ccc;
            border-left: 5px solid #3498db;
            margin-bottom: 15px;
            border-radius: 6px;
        }
    </style>
</head>
<body>

<h2>🔍 Employee Number Search</h2>
<form method="post" action="search.php">
    <label for="employeeNumber">Select Employee Number:</label>
    <select name="employeeNumber" id="employeeNumber">
        <?php
        $employeeNumbers = getEmployeeNumbers($dbc);
        if ($employeeNumbers) {
            while ($row = mysqli_fetch_assoc($employeeNumbers)) {
                echo "<option value='" . $row['employeeNumber'] . "'>" . $row['employeeNumber'] . "</option>";
            }
        }
        ?>
    </select>
    <br>
    <button type="submit" name="employeeSearch">Search Employee</button>
</form>

<hr>

<h2>📅 Order Date Range Search</h2>
<form method="post" action="search.php">
    <label for="year">Year:</label>
    <select name="year" id="year">
        <?php for ($i = 2020; $i <= 2025; $i++) echo "<option value='$i'>$i</option>"; ?>
    </select>

    <label for="month">Month:</label>
    <select name="month" id="month">
        <?php for ($i = 1; $i <= 12; $i++) echo "<option value='$i'>$i</option>"; ?>
    </select>

    <label for="day">Day:</label>
    <select name="day" id="day">
        <?php for ($i = 1; $i <= 31; $i++) echo "<option value='$i'>$i</option>"; ?>
    </select>
    <br>
    <button type="submit" name="orderSearch">Search Orders</button>
</form>

</body>
</html>
